@@ -195,9 +195,9 @@ detectFronts_BelkinOReilly2009 <- function(x, finalSmooth, intermediate, ...){
   filteredV <- convolution2D(X = preMatrix, kernel = sobelV, noNA = TRUE)
 
   # Normalize values
-  # normfactor <- sum(abs(sobelKernel), na.rm = TRUE)
-  # filteredH <- filteredH/normfactor
-  # filteredV <- filteredV/normfactor
+  normfactor <- sum(abs(sobelKernel), na.rm = TRUE)
+  filteredH <- filteredH/normfactor
+  filteredV <- filteredV/normfactor
 
   if(intermediate){
     output[,,3] <- filteredH
